<?php

namespace App\Service\OnChange;

class OnChangeDefault implements OnChangeInterface
{
    public function validate(mixed $data, OnChangeContext $context): void {}

    public function preProcess(mixed $data, OnChangeContext $context): mixed {
        return $data;
    }

    public function beforeChange(mixed $data, OnChangeContext $context): void {}

    public function onChange(mixed $data, OnChangeContext $context): void {}
}
